You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@datasketches.apache.org by le...@apache.org on 2022/06/22 23:25:00 UTC

[datasketches-java] branch master updated: Oops, forgot to update the javadoc in the last push.

This is an automated email from the ASF dual-hosted git repository.

leerho pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/datasketches-java.git


The following commit(s) were added to refs/heads/master by this push:
     new 7aed20ac Oops, forgot to update the javadoc in the last push.
7aed20ac is described below

commit 7aed20ac52ba3bb18f3a427fac4edd94e9f8bf30
Author: Lee Rhodes <le...@users.noreply.github.com>
AuthorDate: Wed Jun 22 16:24:55 2022 -0700

    Oops, forgot to update the javadoc in the last push.
    
    This does not change any code.
---
 src/main/java/org/apache/datasketches/Util.java | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/src/main/java/org/apache/datasketches/Util.java b/src/main/java/org/apache/datasketches/Util.java
index d24ada3e..0074506d 100644
--- a/src/main/java/org/apache/datasketches/Util.java
+++ b/src/main/java/org/apache/datasketches/Util.java
@@ -588,7 +588,7 @@ public final class Util {
 
   /**
    * Computes the next larger double in the power series
-   * <i>point = logBase<sup>( i / ppo )</sup></i> given the current point in the series.
+   * <i>point = logBase<sup>( i / ppb )</sup></i> given the current point in the series.
    * For illustration, this can be used in a loop as follows:
    *
    * <pre>{@code
@@ -604,19 +604,19 @@ public final class Util {
    *     //1 2 3 4 6 8 11 16 23 32 45 64 91 128 181 256 362 512 724 1024
    * }</pre>
    *
    * @param ppo Points-Per-Octave, or the number of points per integer powers of 2 in the series.
    * @param curPoint the current point of the series. Must be &ge; 1.0.
    * @param roundToInt if true the output will be rounded to the nearest integer.
    * @param logBase the desired base of the logarithms
    * @return the next point in the power series.
    */
-  public static double powerSeriesNextDouble(final int ppo, final double curPoint,
+  public static double powerSeriesNextDouble(final int ppb, final double curPoint,
       final boolean roundToInt, final double logBase) {
     final double cur = curPoint < 1.0 ? 1.0 : curPoint;
-    double gi = round(logBaseOfX(logBase, cur) * ppo ); //current generating index
+    double gi = round(logBaseOfX(logBase, cur) * ppb ); //current generating index
     double next;
     do {
-      final double n = pow(logBase, ++gi / ppo);
+      final double n = pow(logBase, ++gi / ppb);
       next = roundToInt ? round(n) : n;
     } while (next <= cur);
     return next;


---------------------------------------------------------------------
@@ -604,19 +604,19 @@ public final class Util {
    * }</pre>
    *
-   * @param ppo Points-Per-Octave, or the number of points per integer powers of 2 in the series.
+   * @param ppb Points-Per-Base, or the number of points per integer powers of base in the series.
    * @param curPoint the current point of the series. Must be &ge; 1.0.
    * @param roundToInt if true the output will be rounded to the nearest integer.
To unsubscribe, e-mail: commits-unsubscribe@datasketches.apache.org
For additional commands, e-mail: commits-help@datasketches.apache.org